torchcurves.functional
======================

.. currentmodule:: torchcurves.functional

Normalization
-------------
Functions for normalizing inputs to the :math:`[-1, 1]` interval, required by most parametric curves.

.. autosummary::
    :toctree: generated
    :nosignatures:

   clamp
   rational


Parametrized curves
-------------------
Vectorized parametric curve evaluation functions.

.. autosummary::
   :toctree: generated
   :nosignatures:

   bspline_curves
   bspline_embeddings
   legendre_curves


Utilities
---------

.. autosummary::
   :toctree: generated
   :nosignatures:

   uniform_augmented_knots
